@@ -6,9 +6,10 @@ use warnings;
 use DateTime;
 use Error::Pure qw(err);
 use Mo qw(build is);
-use Mo::utils 0.28 qw(check_isa check_length check_number_id check_required);
+use Mo::utils 0.28 qw(check_isa check_length check_required);
+use Mo::utils::Number qw(check_positive_natural);
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 has id => (
 	is => 'ro',
@@ -29,18 +30,18 @@ has valid_to => (
 sub BUILD {
 	my $self = shift;
 
-	# Check id.
-	check_number_id($self, 'id');
+	# Check 'id'.
+	check_positive_natural($self, 'id');
 
-	# Check hash name.
+	# Check 'name'.
 	check_required($self, 'name');
 	check_length($self, 'name', 50);
 
-	# Check valid_from.
+	# Check 'valid_from'.
 	check_required($self, 'valid_from');
 	check_isa($self, 'valid_from', 'DateTime');
 
-	# Check valid_to.
+	# Check 'valid_to'.
 	check_isa($self, 'valid_to', 'DateTime');
 	if (defined $self->{'valid_to'}
 		&& DateTime->compare($self->{'valid_from'}, $self->{'valid_to'}) != -1) {
@@ -161,8 +162,6 @@ Returns L<DateTime> object or undef.
 
  new():
          From Mo::utils:
-                 Parameter 'id' must be a natural number.
-                         Value: %s
                  Parameter 'name' has length greater than '50'.
                          Value: %s
                  Parameter 'name' is required.
@@ -177,6 +176,9 @@ Returns L<DateTime> object or undef.
                          Value: %s
                          Valid from: %s
 
+         From Mo::utils::Number::check_positive_natural():
+                 Parameter 'id' must be a positive natural number.
+
 =head1 EXAMPLE
 
 =for comment filename=create_and_print_hash_type.pl
@@ -212,7 +214,8 @@ Returns L<DateTime> object or undef.
 L<DateTime>,
 L<Error::Pure>,
 L<Mo>,
-L<Mo::utils>.
+L<Mo::utils>,
+L<Mo::utils::Number>.
 
 =head1 REPOSITORY
 
@@ -226,12 +229,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2023-2024 Michal Josef Špaček
+© 2023-2025 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
